"""An application for running my Markdown-based sites.

SPDX-FileCopyrightText: © 2020 Brian S. Stephan <bss@incorporeal.org>
SPDX-License-Identifier: AGPL-3.0-or-later
"""
import json
import logging
import os
from logging.config import dictConfig

from termcolor import cprint

from incorporealcms.config import Config


def init_instance(instance_path: str, extra_config: dict = None):
    """Create the instance context, with allowances for customizing path and test settings."""
    # load the instance config.json, if there is one
    instance_config = os.path.join(instance_path, 'config.json')
    if os.path.isfile(instance_config):
        with open(instance_config, 'r') as config:
            config_dict = json.load(config)
            cprint(f"splicing {config_dict} into the config", 'yellow')
            Config.update(config_dict)

    if extra_config:
        cprint(f"splicing {extra_config} into the config", 'yellow')
        Config.update(extra_config)

    # stash some stuff
    Config.INSTANCE_DIR = os.path.abspath(instance_path)

    dictConfig(Config.LOGGING)
    logger = logging.getLogger(__name__)

    logger.debug("instance dir: %s", Config.INSTANCE_DIR)
